Name:           certbot
Version:        2.11.0
Release:        %mkrel 1
Summary:        A free, automated certificate authority client
Group:          Development/Python
License:        ASL 2.0
URL:            https://github.com/certbot/certbot
Source0:        https://github.com/certbot/certbot/archive/v%{version}/%{name}-%{version}.tar.gz
Source10:       certbot-renew-systemd.service
Source11:       certbot-renew-systemd.timer
Source12:       certbot-sysconfig-certbot
Source13:       README.urpmi

# In order to prevent Sphinx from contacting the network, we ship the necessary intersphinx inventory files ourselves:
# wget -O python.inv https://docs.python.org/3/objects.inv
# wget -O acme-python.inv https://acme-python.readthedocs.io/en/latest/objects.inv
# tar czf object.inv-XXX.tar.gz python.inv acme-python.inv
Source100:      object.inv-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  pkgconfig(python3)

# For the systemd macros
%{?systemd_requires}
BuildRequires:  pkgconfig(libsystemd)

Obsoletes:      certbot-doc < 2.8.0-2

%description
Certbot, previously the Let's Encrypt Client, is EFF's tool to obtain certs
from Let's Encrypt, and (optionally) auto-enable HTTPS on your server.
It can also act as a client for any other CA that uses the ACME protocol.

%prep
%autosetup -n %{name}-%{version} -p1

install -Dpm644 %{SOURCE13} README.urpmi

cd docs
tar xzf %{SOURCE100}

%generate_buildrequires
%pyproject_buildrequires -x docs

%build
%pyproject_wheel

# build documentation
make \
 SPHINXOPTS="-Dintersphinx_mapping.python='python.inv' -Dintersphinx_mapping.acme='acme-python.inv'" \
 -C docs man html
rm -rf docs/_build/html/.docinfo

%install
%pyproject_install
%pyproject_save_files %{name}

# Put the man pages in place
install -pD -t %{buildroot}%{_mandir}/man1 docs/_build/man/%{name}.1
install -pD -t %{buildroot}%{_mandir}/man7 docs/_build/man/%{name}.7
install -Dm 0644 %{SOURCE10} %{buildroot}%{_unitdir}/certbot-renew.service
install -Dm 0644 %{SOURCE11} %{buildroot}%{_unitdir}/certbot-renew.timer
install -Dm 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/sysconfig/certbot

#check
#{__python3} setup.py test
# Make sure the scripts use the expected python versions
#grep -q %{__python3} %{buildroot}%{_bindir}/certbot

%preun
%systemd_preun certbot-renew.timer

%files -f %{pyproject_files}
%license LICENSE.txt
%doc README.rst CHANGELOG.md README.urpmi
%doc docs/_build/html/
%{_bindir}/%{name}
# project uses old letsencrypt dirs for compatibility
%ghost %dir %{_sysconfdir}/letsencrypt
%ghost %dir %{_sharedstatedir}/letsencrypt
%ghost %dir %{_logdir}/letsencrypt
%config %{_sysconfdir}/sysconfig/certbot
%{_unitdir}/certbot-renew.service
%{_unitdir}/certbot-renew.timer
%{_mandir}/man*/%{name}.*


%changelog
* Mon Jun 10 2024 kekepower <kekepower> 2.11.0-1.mga10
+ Revision: 2072430
- Update to version 2.11.0

* Sat Jan 20 2024 wally <wally> 2.8.0-2.mga10
+ Revision: 2032479
- update intersphinx inventories for doc build
- rebuild for py3.12
- use pyproject rpm macros
- drop separate doc pkg

* Wed Dec 06 2023 kekepower <kekepower> 2.8.0-1.mga10
+ Revision: 2013673
- Update to version 2.8.0

* Thu Nov 02 2023 kekepower <kekepower> 2.7.4-1.mga10
+ Revision: 2003547
- Update to version 2.7.4

* Fri Oct 27 2023 kekepower <kekepower> 2.7.3-1.mga10
+ Revision: 2002061
- Update to version 2.7.3

* Fri Oct 20 2023 kekepower <kekepower> 2.7.2-1.mga10
+ Revision: 1999650
- Update to version 2.7.2

* Tue Oct 10 2023 kekepower <kekepower> 2.7.1-1.mga10
+ Revision: 1994169
- Update to version 2.7.1

* Mon Oct 09 2023 kekepower <kekepower> 2.7.0-1.mga10
+ Revision: 1993759
- Update to version 2.7.0

* Tue Aug 29 2023 kekepower <kekepower> 2.6.0-1.mga10
+ Revision: 1981050
- Update to version 2.6.0

* Wed Feb 15 2023 kekepower <kekepower> 2.3.0-1.mga9
+ Revision: 1942744
- Update to version 2.3.0

* Wed Jan 25 2023 kekepower <kekepower> 2.2.0-1.mga9
+ Revision: 1936009
- Update to version 2.2.0

* Thu Dec 15 2022 kekepower <kekepower> 2.1.1-1.mga9
+ Revision: 1923306
- Update to version 2.1.1

* Thu Dec 08 2022 kekepower <kekepower> 2.1.0-1.mga9
+ Revision: 1919302
- Update to version 2.1.0

* Wed Nov 23 2022 kekepower <kekepower> 2.0.0-1.mga9
+ Revision: 1910467
- Update to version 2.0.0

* Fri Nov 11 2022 kekepower <kekepower> 1.32.0-1.mga9
+ Revision: 1905468
- Update to version 1.32.0

* Wed Oct 05 2022 kekepower <kekepower> 1.31.0-1.mga9
+ Revision: 1894884
- Update to version 1.31.0

* Fri Sep 09 2022 kekepower <kekepower> 1.30.0-1.mga9
+ Revision: 1886223
- Update to version 1.30.0

* Thu Jul 07 2022 kekepower <kekepower> 1.29.0-1.mga9
+ Revision: 1867920
- Update to version 1.29.0

* Fri Jun 10 2022 kekepower <kekepower> 1.28.0-1.mga9
+ Revision: 1863825
- Update to version 1.28.0

* Wed May 04 2022 kekepower <kekepower> 1.27.0-1.mga9
+ Revision: 1856075
- Update to version 1.27.0

* Wed Apr 06 2022 kekepower <kekepower> 1.26.0-1.mga9
+ Revision: 1846276
- Update to version 1.26.0

* Thu Mar 17 2022 kekepower <kekepower> 1.25.0-1.mga9
+ Revision: 1797242
- Update to version 1.25.0

* Wed Mar 02 2022 kekepower <kekepower> 1.24.0-1.mga9
+ Revision: 1787724
- Update to version 1.24.0

* Thu Feb 10 2022 kekepower <kekepower> 1.23.0-1.mga9
+ Revision: 1772795
- Update to version 1.23.0

* Wed Dec 08 2021 kekepower <kekepower> 1.22.0-1.mga9
+ Revision: 1761148
- Update to version 1.22.0

* Thu Nov 04 2021 kekepower <kekepower> 1.21.0-1.mga9
+ Revision: 1753866
- Update to version 1.21.0

* Thu Oct 07 2021 kekepower <kekepower> 1.20.0-1.mga9
+ Revision: 1749958
- Update to version 1.20.0

* Sun Sep 12 2021 kekepower <kekepower> 1.19.0-1.mga9
+ Revision: 1745225
- Update to version 1.19.0

* Wed Aug 04 2021 kekepower <kekepower> 1.18.0-1.mga9
+ Revision: 1739242
- Update to version 1.18.0

* Tue Jul 06 2021 kekepower <kekepower> 1.17.0-1.mga9
+ Revision: 1735026
- Update to version 1.17.0

* Wed Jun 02 2021 kekepower <kekepower> 1.16.0-1.mga9
+ Revision: 1729378
- Update to version 1.16.0

* Wed May 05 2021 kekepower <kekepower> 1.15.0-1.mga9
+ Revision: 1721450
- Update to version 1.15.0

* Sat Apr 10 2021 kekepower <kekepower> 1.14.0-1.mga9
+ Revision: 1714461
- Update to version 1.14.0

* Thu Mar 04 2021 kekepower <kekepower> 1.13.0-1.mga9
+ Revision: 1697821
- Update to version 1.13.0

* Thu Feb 25 2021 kekepower <kekepower> 1.12.0-1.mga9
+ Revision: 1691071
- Add upstream patch to build docs
- Update to version 1.12.0

* Thu Dec 03 2020 kekepower <kekepower> 1.10.1-1.mga8
+ Revision: 1652273
- Update to version 1.10.1

* Wed Dec 02 2020 kekepower <kekepower> 1.10.0-1.mga8
+ Revision: 1651557
- Update to version 1.10.0

* Wed Oct 07 2020 kekepower <kekepower> 1.9.0-1.mga8
+ Revision: 1632556
- Update to version 1.9.0

* Tue Sep 08 2020 kekepower <kekepower> 1.8.0-1.mga8
+ Revision: 1623703
- Update to version 1.8.0

* Wed Aug 05 2020 kekepower <kekepower> 1.7.0-1.mga8
+ Revision: 1611243
- Update to version 1.7.0

* Wed Jul 08 2020 kekepower <kekepower> 1.6.0-1.mga8
+ Revision: 1602921
- Update to version 1.6.0

* Mon Jun 08 2020 kekepower <kekepower> 1.5.0-1.mga8
+ Revision: 1591058
- Update to version 1.5.0

* Tue May 19 2020 ovitters <ovitters> 1.4.0-1.mga8
+ Revision: 1586170
- require the right acme version
+ kekepower <kekepower>
- Update to version 1.4.0

* Thu Mar 05 2020 kekepower <kekepower> 1.3.0-1.mga8
+ Revision: 1554146
- Fix rel
- Update to version 1.3.0

* Thu Feb 20 2020 umeabot <umeabot> 1.2.0-2.mga8
+ Revision: 1546962
- Mageia 8 Mass Rebuild

* Thu Feb 06 2020 kekepower <kekepower> 1.2.0-1.mga8
+ Revision: 1487346
- Update to version 1.2.0

* Wed Jan 22 2020 kekepower <kekepower> 1.1.0-1.mga8
+ Revision: 1482112
- Update to version 1.1.0

* Sun Dec 08 2019 guillomovitch <guillomovitch> 1.0.0-1.mga8
+ Revision: 1465168
- new version 1.0.0

* Wed Nov 06 2019 kekepower <kekepower> 0.40.1-1.mga8
+ Revision: 1458319
- Update to version 0.40.1

* Sat Oct 05 2019 guillomovitch <guillomovitch> 0.39.0-1.mga8
+ Revision: 1449738
- new version 0.39
+ kekepower <kekepower>
- Update to version 0.38.0

* Thu Aug 22 2019 kekepower <kekepower> 0.37.2-1.mga8
+ Revision: 1431281
- Update to version 0.37.2

* Fri Aug 09 2019 kekepower <kekepower> 0.37.1-1.mga8
+ Revision: 1428328
- Update to version 0.37.1

* Thu Aug 08 2019 kekepower <kekepower> 0.37.0-1.mga8
+ Revision: 1428236
- Update to version 0.37.0
+ guillomovitch <guillomovitch>
- new version 0.36.0

* Sun Jun 30 2019 kekepower <kekepower> 0.35.1-1.mga8
+ Revision: 1416417
- Update to version 0.35.1

* Wed May 08 2019 kekepower <kekepower> 0.34.2-1.mga7
+ Revision: 1396647
- Update to version 0.34.2

* Sat Apr 06 2019 kekepower <kekepower> 0.33.1-1.mga7
+ Revision: 1386298
- Update to version 0.33.1

* Thu Apr 04 2019 kekepower <kekepower> 0.33.0-1.mga7
+ Revision: 1385652
- Update to version 0.33.0

* Thu Mar 07 2019 kekepower <kekepower> 0.32.0-1.mga7
+ Revision: 1372559
- BR python3dist(pyyaml)
- BR python3dist(pytest)
- Update to version 0.32.0

* Fri Feb 08 2019 kekepower <kekepower> 0.31.0-1.mga7
+ Revision: 1364093
- Update to version 0.31.0

* Fri Jan 25 2019 kekepower <kekepower> 0.30.2-1.mga7
+ Revision: 1360697
- Update to version 0.30.2

* Fri Jan 25 2019 kekepower <kekepower> 0.30.1-1.mga7
+ Revision: 1360594
- Update to version 0.30.1

* Mon Jan 07 2019 kekepower <kekepower> 0.30.0-3.mga7
+ Revision: 1350999
- Fix Requires for python-zope-*

* Mon Jan 07 2019 kekepower <kekepower> 0.30.0-2.mga7
+ Revision: 1350768
- Add patch to use sphinx-build-3
- Switch to python3dist()
- Rebuild for Python 3.7

* Thu Jan 03 2019 kekepower <kekepower> 0.30.0-1.mga7
+ Revision: 1348759
- Update to version 0.30.0

* Sun Dec 30 2018 kekepower <kekepower> 0.29.1-2.mga7
+ Revision: 1347216
- Update to version 0.29.1

* Fri Dec 14 2018 zezinho <zezinho> 0.28.0-2.mga7
+ Revision: 1341163
- added requires on python3-pyasn1

* Thu Nov 08 2018 guillomovitch <guillomovitch> 0.28.0-1.mga7
+ Revision: 1329023
- new version 0.28.0

* Thu Sep 20 2018 umeabot <umeabot> 0.27.1-2.mga7
+ Revision: 1277796
- Mageia 7 Mass Rebuild

* Sat Sep 08 2018 guillomovitch <guillomovitch> 0.27.1-1.mga7
+ Revision: 1257845
- new version 0.27.1

* Sun Aug 19 2018 guillomovitch <guillomovitch> 0.26.1-1.mga7
+ Revision: 1252834
- new version 0.26.1

* Tue Jun 26 2018 guillomovitch <guillomovitch> 0.25.1-1.mga7
+ Revision: 1239788
- new version 0.25.1

* Sat May 05 2018 guillomovitch <guillomovitch> 0.24.0-1.mga7
+ Revision: 1226369
- new version 0.24.0

* Wed Mar 14 2018 guillomovitch <guillomovitch> 0.22.0-1.mga7
+ Revision: 1209543
- new version 0.22

* Thu Feb 08 2018 guillomovitch <guillomovitch> 0.21.1-1.mga7
+ Revision: 1199769
- new version 0.21.1

* Tue Dec 12 2017 mitya <mitya> 0.20.0-1.mga7
+ Revision: 1182273
- New version 0.20.0

* Sun Nov 05 2017 mitya <mitya> 0.19.0-1.mga7
+ Revision: 1175971
- New version 0.19.0

* Sat Aug 05 2017 pterjan <pterjan> 0.14.2-3.mga7
+ Revision: 1135194
- Rebuild for python 3.6

* Thu Jun 08 2017 mitya <mitya> 0.14.2-2.mga6
+ Revision: 1107351
- fix BRs for systemd macro
- README.urpmi: s/Fedora/Mageia/

* Sat May 27 2017 mitya <mitya> 0.14.2-1.mga6
+ Revision: 1105149
- New version 0.14.2

* Wed May 24 2017 mitya <mitya> 0.14.1-2.mga6
+ Revision: 1104398
- remove unneeded %%post
- added %%preun

* Wed May 24 2017 mitya <mitya> 0.14.1-1.mga6
+ Revision: 1104377
- Mageify
- build mans & docs
- imported package certbot

